@@ -18,6 +18,3 @@ else
   cmake .. -DCMAKE_BUILD_TYPE=${CMAKE_BUILD_TYPE}
   make -j$(nproc --all)
 fi
-
-# run unit tests
-./tests/run_tests
