@@ -55,7 +55,13 @@ bool CtConfig::load_from_file(const fs::path& filepath)
     if (fs::exists(filepath))
     {
         _uKeyFile = std::make_unique<Glib::KeyFile>();
-        _uKeyFile->load_from_file(filepath.string());
+        try {
+            _uKeyFile->load_from_file(filepath.string());
+        }
+        catch (Glib::Error& error) {
+            spdlog::error("CtConfig {}: {}", filepath, error.what());
+            return false;
+        }
         _populate_data_from_keyfile();
         _uKeyFile.reset(nullptr);
         spdlog::debug("{} parsed", filepath);
@@ -302,6 +308,7 @@ void CtConfig::_populate_keyfile_from_data()
     _uKeyFile->set_string(_currentGroup, "tt_def_fg", ttDefFg);
     _uKeyFile->set_string(_currentGroup, "tt_def_bg", ttDefBg);
     _uKeyFile->set_string(_currentGroup, "monospace_bg", monospaceBg);
+    _uKeyFile->set_boolean(_currentGroup, "ms_dedic_font", msDedicatedFont);
     _uKeyFile->set_string(_currentGroup, "monospace_font", monospaceFont);
     _uKeyFile->set_string(_currentGroup, "color_palette", colorPalette);
     _uKeyFile->set_string(_currentGroup, "col_link_webs", colLinkWebs);
@@ -581,6 +588,7 @@ void CtConfig::_populate_data_from_keyfile()
     _populate_string_from_keyfile("tt_def_fg", &ttDefFg);
     _populate_string_from_keyfile("tt_def_bg", &ttDefBg);
     _populate_string_from_keyfile("monospace_bg", &monospaceBg);
+    _populate_bool_from_keyfile("ms_dedic_font", &msDedicatedFont);
     _populate_string_from_keyfile("monospace_font", &monospaceFont);
     _populate_string_from_keyfile("color_palette", &colorPalette);
     _populate_string_from_keyfile("col_link_webs", &colLinkWebs);
